import re
import tags


def skype(text):
    return tags.filtered_tokens(text, "skype", r'[\w@:.\d_]+')


def instagram(text):
    instagram_id_pattern = r'[\w\d._]+'
    instagram_url_pattern = r'instagram\.com/(' + instagram_id_pattern + ')'

    tricky_tokens = tags.filtered_tokens(text, "instagram", instagram_id_pattern)
    url_tokens = re.findall(instagram_url_pattern, text, flags=re.IGNORECASE | re.UNICODE)

    return [t for t in tags.unique_tokens(tricky_tokens + url_tokens) if len(t) >= 4]


def twitter(text):
    id_pattern = r'[@\w\d._]+'
    url_pattern = r'twitter.com/(' + id_pattern + r')'
    identifier = "twitter"
    handles = tags.filter_tokens_or_urls(text, identifier, id_pattern, url_pattern)
    return [t.replace("@", "") for t in handles]


def kik(text):
    id_pattern = r'[\w\d._]+'
    return tags.filtered_tokens(text, "kik", id_pattern)


def youtube(text):
    id_pattern = r'[\w\d._]+'
    url_pattern = r'youtube.com/(?:channel|user)/(' + id_pattern + r')'
    identifier = "youtube"
    return tags.filter_tokens_or_urls(text, identifier, id_pattern, url_pattern)


def google_plus(text):
    id_pattern = r'(:?\d+|\+[\w\d]+)'
    url_pattern = r'plus\.google\.com/(' + id_pattern + r')'
    identifier = "google"
    return tags.filter_tokens_or_urls(text, identifier, id_pattern, url_pattern)


def facebook(text):
    id_pattern = r'[\w\d._]+'
    url_patterns = (
        r'facebook.com/(?!profile\.php)(' + id_pattern + r')',
        r'facebook.com/profile.php?.*?id=(\d+)',
    )
    identifier = "facebook"
    return tags.filter_tokens_or_urls(text, identifier, id_pattern, url_patterns)


def twitch(text):
    id_pattern = r'[\w\d._]+'
    url_pattern = r'twitch.tv/(' + id_pattern + r')'
    identifier = "twitch"
    standard_tags = tags.filter_tokens_or_urls(text, identifier, id_pattern, url_pattern)
    general_tags = re.findall(url_pattern, text, flags=re.IGNORECASE | re.UNICODE)
    return tags.unique_tokens(standard_tags + [t for t in general_tags if len(t) >= 4])
