import re
import tags


def age(text):
    possible_ages = tags.find_tokens(text, "age", min_length=2)
    ages = []
    for an_age in possible_ages:
        match = re.search(r"[\d\-+]+", an_age)
        if not match:
            continue
        ages.append(match.group(0))
    return ages


def _name_tokens(text):
    pattern = r'^[\w\']+$'
    possible_names = tags.find_tokens(text, "name", min_length=2)
    return [n for n in possible_names if re.match(pattern, n)]


def first_name(text):
    possible_names = _name_tokens(text)
    return [possible_names[0]] if len(possible_names) > 0 else []


def last_name(text):
    possible_names = _name_tokens(text)

    if len(possible_names) < 2:
        return []

    if len(possible_names) == 2:
        return [possible_names[1]]

    # Handle cases like FIRSTNAME de Boer
    if possible_names[1][0].lower() == possible_names[1][0]:
        return [" ".join(possible_names[1:2])]

    return [possible_names[1]]


def phone(text):
    phone_patterns = (
        r'\d{3}-\d{3}-\d{4}$',
        r'\d{10}$',
        r'\(\d{3}\) ?\d{3}-\d{4}$'
    )

    splitters = [",", ";"]

    possible_numbers = (
        tags.find_tokens(text, "phone", min_length=2, splitters=splitters) +
        tags.find_tokens(text, "number", min_length=2, splitters=splitters) +
        tags.find_tokens(text, "tel", min_length=2, splitters=splitters) +
        tags.find_tokens(text, "phone #", min_length=2, splitters=splitters)
    )

    return [n for n in possible_numbers if any([p for p in phone_patterns if re.match(p, n)])]
