import pprint
import tornado.web
import tornado.process
from tornado.log import gen_log
import doxscrapers.scrapers


SITES = {
    "facebook": doxscrapers.scrapers.facebook,
    "instagram": doxscrapers.scrapers.instagram,
    "youtube": doxscrapers.scrapers.youtube,
    "twitter": doxscrapers.scrapers.twitter,
    "twitch": doxscrapers.scrapers.twitch,
    "gplus": doxscrapers.scrapers.gplus,
}


COMMAND_LINE_ARGS = {}
def set_arg(name, value):
    COMMAND_LINE_ARGS[name] = value


class SocialExtractionHandler(tornado.web.RequestHandler):

    def _log_error(self, data, account, service):
        gen_log.error("Error in scraping social service.\nAccount: %(account)s\nService: %(service)s\n%(msg)s", {
            "account": account,
            "service": service,
            "msg": pprint.pformat(data)
        })
        self.write(data)
        self.finish()


    @tornado.gen.coroutine
    def post(self):
        response = {'error': True}
        try:
            account = self.get_body_argument('account')
            service = self.get_body_argument('service')
        except tornado.web.MissingArgumentError, exc:
            response['msg'] = "Missing POST argument '{}'".format(exc.arg_name)
            self._log_error(response, account, service)
            return

        if service not in SITES.keys():
            response['msg'] = 'Invalid "service", saw {}, must be one of {}'.format(
                service, ",".join(SITES.keys())
            )
            self._log_error(response, account, service)
            return

        root_dir = COMMAND_LINE_ARGS['CUR_DIR']
        binary = COMMAND_LINE_ARGS['BINARY']

        firefox_log_arg = ""
        if COMMAND_LINE_ARGS["LOG_FILE"]:
            firefox_log_arg = "-l {}".format(COMMAND_LINE_ARGS["LOG_FILE"])

        command_params = (root_dir, account, service, binary, firefox_log_arg)
        command_args = "{}/client.py -u {} -s {} -b {} {}".format(*command_params)
        kwargs = {
            "stdout": tornado.process.Subprocess.STREAM,
            "stderr": tornado.process.Subprocess.STREAM,
            "shell": True
        }

        num_tries = 3
        while num_tries > 0:
            process = tornado.process.Subprocess(command_args, **kwargs)
            stdout_text, stdout_error = yield [
                process.stdout.read_until_close(),
                process.stderr.read_until_close()
            ]

            if not stdout_error.strip():
                break
            num_tries =- 1

        if stdout_error.strip():
            response["msg"] = stdout_error
            self._log_error(response, account, service)
            return

        response['msg'] = stdout_text
        response['error'] = False
        gen_log.debug("Completed scrape for '%(account)s' on '%(service)s'", {
            "account": account,
            "service": service,
        })
        self.write(response)
        self.finish()
